pub enum DeletePolicy {
DeleteWins,
UpdateWins,
}Expand description
Policy for delete vs update conflicts.
Determines what happens when one branch deletes a key while another branch modifies it.
Variants
DeleteWins
Deletes win over updates.
If one branch deletes a key and another modifies it, the key will be absent from the merged result.
UpdateWins
Updates win over deletes.
If one branch deletes a key and another modifies it, the key will be present with the updated value.