pub enum Diff {
Added {
key: Vec<u8>,
val: Vec<u8>,
},
Removed {
key: Vec<u8>,
val: Vec<u8>,
},
Changed {
key: Vec<u8>,
old: Vec<u8>,
new: Vec<u8>,
},
}Expand description
Difference between two trees
Represents a single change between a base tree and another tree.
Variants
Added
Entry exists in the new tree but not in the base tree
Removed
Entry exists in the base tree but not in the new tree
Changed
Entry exists in both trees but with different values
Implementations