pub enum FileNodeStoreError {
Io {
path: PathBuf,
source: Error,
},
InvalidKey {
message: String,
},
CidMismatch {
path: PathBuf,
expected: Cid,
actual: Cid,
},
InvalidPath {
path: PathBuf,
message: String,
},
Manifest {
path: PathBuf,
message: String,
},
LockPoisoned(String),
}Expand description
Error type for FileNodeStore.
Variants
Io
Filesystem I/O failed for the given path.
InvalidKey
A store key was not a 32-byte CID.
CidMismatch
A node object’s bytes do not match its CID key.
Fields
InvalidPath
The store namespace contains an invalid path or filename.
Manifest
A named root manifest could not be encoded or decoded.
Fields
LockPoisoned(String)
A local manifest lock was poisoned.