pub enum ManifestUpdate {
Applied,
Conflict {
current: Option<RootManifest>,
},
}Expand description
Result of a named-root compare-and-swap update.
Variants
Applied
The expected manifest matched and the update was applied.
Conflict
The expected manifest did not match the current manifest.
Fields

current: Option<RootManifest>Current manifest stored under the requested name.
Implementations
Sourceimpl ManifestUpdate
impl ManifestUpdate
Sourcepub fn is_applied(&self) -> bool
pub fn is_applied(&self) -> bool
Whether the update was applied.
Sourcepub fn is_conflict(&self) -> bool
pub fn is_conflict(&self) -> bool
Whether the update failed because the current manifest differed.
Sourcepub fn current(&self) -> Option<&RootManifest>
pub fn current(&self) -> Option<&RootManifest>
Current manifest for conflicts, or None for applied updates.