pub enum MergeFastPath {
BranchesEqual,
LeftUnchanged,
RightUnchanged,
}Expand description
Root-level fast path used by a merge.
Variants
BranchesEqual
left and right already reference the same root.
LeftUnchanged
left is unchanged from base, so right is the merge result.
RightUnchanged
right is unchanged from base, so left is the merge result.