pub enum NamedRootUpdate {
Applied,
Conflict {
current: Option<Tree>,
},
}Expand description
Result of a named-root compare-and-swap through a crate::Prolly manager.
Variants
Applied
The expected tree matched and the update was applied.
Conflict
The expected tree did not match the current named root.
Implementations
Sourceimpl NamedRootUpdate
impl NamedRootUpdate
Sourcepub fn is_applied(&self) -> bool
pub fn is_applied(&self) -> bool
Whether the update was applied.
Sourcepub fn is_conflict(&self) -> bool
pub fn is_conflict(&self) -> bool
Whether the update failed because the current tree differed.