pub enum RemoteManifestUpdate {
Applied,
Conflict {
current: Option<Vec<u8>>,
},
}Expand description
Result of a backend-level root compare-and-swap.
Variants
Applied
The expected manifest matched and the update was applied.
Conflict
The expected manifest did not match the current manifest bytes.