pub enum StructuralDiffMarker {
Compare {
base_cid: Cid,
other_cid: Cid,
span_end: Option<Vec<u8>>,
},
Added {
cid: Cid,
},
Removed {
cid: Cid,
},
}Expand description
Public marker for one suspended structural diff frame.
Variants
Compare
Compare two subtrees with the same structural span.
Added
Emit all entries from a subtree added on the other side.
Removed
Emit all entries from a subtree removed from the base side.