pub enum ValueRef {
Inline(Vec<u8>),
Blob(BlobRef),
}Expand description
Value stored in a leaf by the large-value helper layer.
Variants
Implementations
Sourceimpl ValueRef
impl ValueRef
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Encode this reference as a deterministic leaf value envelope.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
Decode a value reference envelope.
Sourcepub fn from_stored_bytes(bytes: &[u8]) -> Result<Self, Error>
pub fn from_stored_bytes(bytes: &[u8]) -> Result<Self, Error>
Decode a stored value, treating non-envelope bytes as inline values.
Sourcepub fn inline_requires_escape(value: &[u8]) -> bool
pub fn inline_requires_escape(value: &[u8]) -> bool
Whether raw inline bytes must be escaped to avoid being interpreted as a value reference envelope.