pub async fn content_references_async<S: AsyncStore>(
store: &S,
root: &TypedContentRoot,
) -> Result<Vec<TypedContentRoot>, Error>Expand description
Load one authenticated object and return its typed references through AsyncStore.
pub async fn content_references_async<S: AsyncStore>(
store: &S,
root: &TypedContentRoot,
) -> Result<Vec<TypedContentRoot>, Error>Load one authenticated object and return its typed references through AsyncStore.