verify_authenticated_proof_bundle

Function verify_authenticated_proof_bundle 

pub fn verify_authenticated_proof_bundle(
    envelope_bytes: &[u8],
    secret: &[u8],
    now_millis: Option<u64>,
) -> Result<AuthenticatedProofBundleVerification, Error>
Decode, authenticate, and verify serialized proof envelope bytes.

This is the one-shot verifier for transport payloads created by AuthenticatedProofEnvelope::to_bytes. A malformed envelope is returned as an error. An envelope with a bad signature or invalid time bounds returns a verification record with valid = false and does not attempt proof verification. An authenticated envelope carrying a malformed proof bundle returns valid = false with proof_error populated.