Module remote_conformance

Module remote_conformance 

Reusable backend conformance checks for provider implementations.

Provider crates should run this against their SDK-backed implementation in addition to any provider-specific transactional tests.

Functions

assert_remote_backend_contract
Assert the common backend contract needed by remote prolly adapters.
assert_remote_backend_transaction_contract
Assert the optional backend transaction contract. Providers that return true from supports_transactions should run this in addition to the base backend contract.