pub async fn assert_remote_backend_contract<B>(backend: &B)Expand description
Assert the common backend contract needed by remote prolly adapters.
pub async fn assert_remote_backend_contract<B>(backend: &B)Assert the common backend contract needed by remote prolly adapters.