pub struct AsyncProximityMap<S: AsyncStore> { /* private fields */ }Implementations
Sourceimpl<S> AsyncProximityMap<SearchIo<S>>
impl<S> AsyncProximityMap<SearchIo<S>>
Sourcepub async fn search_with_runtime(
&self,
request: SearchRequest<'_>,
control: AsyncSearchControl,
) -> Result<SearchResult, Error>
pub async fn search_with_runtime( &self, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>
Execute native async search with physical I/O derived from the shared runtime rather than from logical object consumption.
Sourcepub async fn search_with_accelerators(
&self,
accelerators: &AsyncAcceleratorSet,
request: SearchRequest<'_>,
control: AsyncSearchControl,
) -> Result<SearchResult, Error>
pub async fn search_with_accelerators( &self, accelerators: &AsyncAcceleratorSet, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>
Plan and execute native, eligible-exact, PQ, or HNSW search through an async-only store using the same logical planner as synchronous search.
Sourceimpl<S> AsyncProximityMap<S>
impl<S> AsyncProximityMap<S>
pub async fn load(store: S, descriptor_cid: Cid) -> Result<Self, Error>
pub fn tree(&self) -> &ProximityTree
pub async fn search( &self, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>