pub struct BlobGcReachability {
pub live_blobs: Vec<BlobRef>,
pub live_blob_count: usize,
pub live_blob_bytes: u64,
pub scanned_nodes: usize,
pub scanned_values: usize,
}Expand description
Live blob set discovered from one or more retained tree roots.
Fields
live_blobs: Vec<BlobRef>Reachable content-addressed blob references, sorted by CID bytes.
live_blob_count: usizeNumber of unique reachable blobs.
live_blob_bytes: u64Total byte weight of unique reachable blobs.
scanned_nodes: usizeNumber of reachable tree nodes scanned while marking blob references.
scanned_values: usizeNumber of reachable leaf values inspected while marking blob references.
Implementations