pub struct BlobGcSweep {
pub plan: BlobGcPlan,
pub deleted_blobs: usize,
pub deleted_blob_bytes: u64,
}Expand description
Result of sweeping a blob garbage-collection plan.
Fields
plan: BlobGcPlanPlan used to decide which candidate blobs were unreachable.
deleted_blobs: usizeNumber of blobs deleted from the backing blob store.
deleted_blob_bytes: u64Blob bytes deleted from the backing blob store.