CrdtConfig

Struct CrdtConfig 

pub struct CrdtConfig {
    pub strategy: MergeStrategy,
    pub delete_policy: DeletePolicy,
    pub timestamp_extractor: Option<TimestampExtractor>,
}
Configuration for conflict-free merging.

Controls how the CRDT merger resolves conflicts between concurrent modifications.

Example

use prolly::{CrdtConfig, MergeStrategy, DeletePolicy};

let config = CrdtConfig {
    strategy: MergeStrategy::LastWriterWins,
    delete_policy: DeletePolicy::UpdateWins,
    timestamp_extractor: None,
};

Fields

strategy: MergeStrategy

The merge strategy to use for resolving conflicts.

delete_policy: DeletePolicy

Policy for delete vs update conflicts.

timestamp_extractor: Option<TimestampExtractor>

Function to extract timestamp from value (for LWW).

If None, values are assumed to be in TimestampedValue format. If extraction fails, timestamp defaults to 0.

Implementations

Source

impl CrdtConfig

pub fn lww() -> Self

Create a new CrdtConfig with LWW strategy.

pub fn multi_value() -> Self

Create a new CrdtConfig with MV strategy.

pub fn custom<F>(merge_fn: F) -> Self
where F: Fn(&Conflict) -> CrdtResolution + Send + Sync + 'static,

Create a new CrdtConfig with a custom merge function.

The callback must be pure and deterministic and may be invoked more than once for a conflict while the engine changes execution paths.

pub fn with_delete_policy(self, policy: DeletePolicy) -> Self

Set the delete policy.

pub fn with_timestamp_extractor<F>(self, extractor: F) -> Self
where F: Fn(&[u8]) -> u64 + Send + Sync + 'static,

Set a custom timestamp extractor for LWW strategy.