DiffPage

Struct DiffPage 

pub struct DiffPage {
    pub diffs: Vec<Diff>,
    pub next_cursor: Option<RangeCursor>,
}
A bounded page of diff results.

next_cursor is Some when another call should resume after the last diff entry in this page. It is None when the scan reached the end bound or the end of both trees.

Fields

diffs: Vec<Diff>next_cursor: Option<RangeCursor>