pub struct FileBlobStore { /* private fields */ }Expand description
Durable filesystem-backed blob store.
Blobs are stored under blobs/sha256/aa/bb/<cid-hex> below the configured
root directory. Writes are content-addressed and idempotent; a completed
write is published with an atomic rename inside the target directory.
Implementations
Sourceimpl FileBlobStore
impl FileBlobStore
Sourcepub fn open(root: impl Into<PathBuf>) -> Result<Self, FileBlobStoreError>
pub fn open(root: impl Into<PathBuf>) -> Result<Self, FileBlobStoreError>
Open or create a filesystem blob store rooted at root.
Sourcepub fn namespace_dir(&self) -> PathBuf
pub fn namespace_dir(&self) -> PathBuf
Return the namespace directory that contains sharded blob files.
Sourcepub fn path_for_ref(&self, reference: &BlobRef) -> PathBuf
pub fn path_for_ref(&self, reference: &BlobRef) -> PathBuf
Return the filesystem path for a blob reference.