pub struct GcPlan {
pub reachability: GcReachability,
pub candidate_nodes: usize,
pub reclaimable_cids: Vec<Cid>,
pub reclaimable_nodes: usize,
pub reclaimable_bytes: usize,
pub missing_candidates: usize,
}Expand description
Dry-run garbage-collection plan for an explicit candidate set.
Fields
reachability: GcReachabilityReachability report for the retained roots.
candidate_nodes: usizeNumber of unique candidate CIDs inspected.
reclaimable_cids: Vec<Cid>Unreachable candidate CIDs present in the store, sorted by CID bytes.
reclaimable_nodes: usizeNumber of reclaimable candidate nodes.
reclaimable_bytes: usizeSerialized bytes reclaimable from present unreachable candidates.
missing_candidates: usizeCandidate CIDs that were neither reachable nor present in the store.
Implementations
Sourceimpl GcPlan
impl GcPlan
Sourcepub fn reclaimable_cids(&self) -> &[Cid]
pub fn reclaimable_cids(&self) -> &[Cid]
Return reclaimable candidate CIDs in stable byte order.
Sourcepub fn retained_candidate_nodes(&self) -> usize
pub fn retained_candidate_nodes(&self) -> usize
Number of candidate nodes retained because they are still reachable.