pub struct GcReachability {
pub live_cids: Vec<Cid>,
pub live_nodes: usize,
pub live_bytes: usize,
pub leaf_nodes: usize,
pub internal_nodes: usize,
}Expand description
Live node set discovered from one or more retained tree roots.
Fields
live_cids: Vec<Cid>Reachable content-addressed node CIDs, sorted by CID bytes.
live_nodes: usizeNumber of reachable nodes.
live_bytes: usizeSerialized byte weight of reachable nodes as encoded by the current node serializer.
leaf_nodes: usizeNumber of reachable leaf nodes.
internal_nodes: usizeNumber of reachable internal nodes.
Implementations