pub struct IndexedSnapshotBundle {
pub format_version: u32,
pub source_map_id: Vec<u8>,
pub source_version: MapVersionId,
pub catalog_map_id: Vec<u8>,
pub catalog_version: MapVersionId,
pub source_tree: Tree,
pub catalog_tree: Tree,
pub control: Option<IndexControl>,
pub indexes: Vec<IndexedSnapshotBundleIndex>,
pub nodes: Vec<SnapshotBundleNode>,
}Expand description
Self-contained, canonical transport for one current coordinated snapshot.
Fields
format_version: u32source_map_id: Vec<u8>source_version: MapVersionIdcatalog_map_id: Vec<u8>catalog_version: MapVersionIdsource_tree: Treecatalog_tree: Treecontrol: Option<IndexControl>indexes: Vec<IndexedSnapshotBundleIndex>nodes: Vec<SnapshotBundleNode>Implementations
Sourceimpl IndexedSnapshotBundle
impl IndexedSnapshotBundle
pub fn node_count(&self) -> usize
pub fn byte_count(&self) -> usize
pub fn digest(&self) -> Result<Cid, Error>
pub fn summary(&self) -> Result<IndexedSnapshotBundleSummary, Error>
Sourcepub fn inspect(bytes: &[u8]) -> Result<IndexedSnapshotBundleSummary, Error>
pub fn inspect(bytes: &[u8]) -> Result<IndexedSnapshotBundleSummary, Error>
Decode, fully verify, and return only compact bundle metadata.
Sourcepub fn verify(&self) -> Result<IndexedSnapshotBundleVerification, Error>
pub fn verify(&self) -> Result<IndexedSnapshotBundleVerification, Error>
Verify hashes, exact reachability, ownership, persisted records, and tree IDs.
Sourcepub fn to_bytes(&self) -> Result<Vec<u8>, Error>
pub fn to_bytes(&self) -> Result<Vec<u8>, Error>
Encode deterministic bytes with fixed field positions and canonical ordering.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>
Decode canonical bytes and reject unsupported versions or trailing data.