pub struct MapComparison<'a, S: Store> { /* private fields */ }Expand description
A version-pinned comparison between two snapshots of the same managed map.
Implementations
Sourceimpl<'a, S: Store> MapComparison<'a, S>
impl<'a, S: Store> MapComparison<'a, S>
Sourcepub fn base(&self) -> &MapVersion
pub fn base(&self) -> &MapVersion
Baseline version.
Sourcepub fn target(&self) -> &MapVersion
pub fn target(&self) -> &MapVersion
Target version.
Sourcepub fn stream_diff<'s>(
&'s self,
) -> Result<Box<dyn Iterator<Item = Result<Diff, Error>> + 's>, Error>
pub fn stream_diff<'s>( &'s self, ) -> Result<Box<dyn Iterator<Item = Result<Diff, Error>> + 's>, Error>
Lazily stream logical differences.
Sourcepub fn diff_page(
&self,
cursor: &RangeCursor,
end: Option<&[u8]>,
limit: usize,
) -> Result<DiffPage, Error>
pub fn diff_page( &self, cursor: &RangeCursor, end: Option<&[u8]>, limit: usize, ) -> Result<DiffPage, Error>
Read one resumable key-cursor diff page.
Sourcepub fn structural_diff_page(
&self,
cursor: Option<&StructuralDiffCursor>,
limit: usize,
) -> Result<StructuralDiffPage, Error>
pub fn structural_diff_page( &self, cursor: Option<&StructuralDiffCursor>, limit: usize, ) -> Result<StructuralDiffPage, Error>
Read one structural diff page while preserving the CID frontier.
Sourcepub fn prove_diff_page(
&self,
cursor: &RangeCursor,
end: Option<&[u8]>,
limit: usize,
) -> Result<ProvedDiffPage, Error>
pub fn prove_diff_page( &self, cursor: &RangeCursor, end: Option<&[u8]>, limit: usize, ) -> Result<ProvedDiffPage, Error>
Read and prove one bounded diff page.
Sourcepub fn stats(&self) -> Result<StatsComparison, Error>
pub fn stats(&self) -> Result<StatsComparison, Error>
Compare shape, entry counts, and serialized size.
Sourcepub fn debug_view(&self) -> Result<TreeDebugComparison, Error>
pub fn debug_view(&self) -> Result<TreeDebugComparison, Error>
Compare shared and rewritten tree nodes.
Sourcepub fn publish_changed_spans<I>(&self, spans: I) -> Result<bool, Error>where
I: IntoIterator<Item = ChangedSpan>,
pub fn publish_changed_spans<I>(&self, spans: I) -> Result<bool, Error>where
I: IntoIterator<Item = ChangedSpan>,
Publish correctness-optional changed-span hints for this transition.
Sourcepub fn changed_spans(&self) -> Result<Option<ChangedSpanHint>, Error>
pub fn changed_spans(&self) -> Result<Option<ChangedSpanHint>, Error>
Load correctness-optional changed-span hints for this transition.