MapMerge

Struct MapMerge 

pub struct MapMerge<'a, S: Store> { /* private fields */ }
A three-way merge pinned to a base, current head, and candidate version.

Implementations

Source

impl<'a, S: Store> MapMerge<'a, S>

pub fn base(&self) -> &MapVersion

Common ancestor selected for the merge.

pub fn head(&self) -> &MapVersion

Head that must still be current when publishing.

pub fn candidate(&self) -> &MapVersion

Candidate version whose changes are being merged.

pub fn stream_conflicts<'s>( &'s self, ) -> Result<Box<dyn Iterator<Item = Result<Conflict, Error>> + 's>, Error>

Lazily stream conflicts without constructing a merged tree.

pub fn merge(&self, resolver: Option<Resolver>) -> Result<Tree, Error>

Build the merged tree without moving head.

pub fn merge_with_policy( &self, policies: &MergePolicyRegistry, ) -> Result<Tree, Error>

Build a merged tree using a prefix/exact-key policy registry.

pub fn crdt_merge(&self, config: &CrdtConfig) -> Result<Tree, Error>

Build a conflict-free merged tree using CRDT semantics.

pub fn crdt_merge_explain(&self, config: &CrdtConfig) -> MergeExplanation

Build a conflict-free merged tree and retain engine diagnostics.

pub fn publish( &self, resolver: Option<Resolver>, ) -> Result<VersionedMapUpdate, Error>

Merge and publish only if the pinned head is still current.

pub fn publish_with_policy( &self, policies: &MergePolicyRegistry, ) -> Result<VersionedMapUpdate, Error>

Merge with policies and CAS-publish the result.

pub fn publish_crdt( &self, config: &CrdtConfig, ) -> Result<VersionedMapUpdate, Error>

CRDT-merge and CAS-publish the result.