pub struct MapVersionPage {
pub versions: Vec<MapVersion>,
pub next_cursor: Option<MapVersionCursor>,
}Expand description
One bounded page of immutable versions in stable version-ID byte order.
Fields
versions: Vec<MapVersion>Cataloged immutable versions.
next_cursor: Option<MapVersionCursor>Cursor for the next page, or None when enumeration is complete.