pub struct MissingNodePlan {
pub required_cids: Vec<Cid>,
pub required_nodes: usize,
pub required_bytes: usize,
pub missing_cids: Vec<Cid>,
pub missing_nodes: usize,
pub missing_bytes: usize,
}Expand description
Dry-run plan for making a destination store able to read one source tree.
required_cids are all node CIDs reachable from the tree root. missing_cids
are the subset not currently present in the destination store. All CIDs are
sorted by raw CID bytes for deterministic transport planning.
Fields
required_cids: Vec<Cid>All reachable node CIDs required by the tree.
required_nodes: usizeNumber of reachable nodes required by the tree.
required_bytes: usizeSerialized bytes for all reachable nodes in the source tree.
missing_cids: Vec<Cid>Required node CIDs not present in the destination store.
missing_nodes: usizeNumber of missing destination nodes.
missing_bytes: usizeSerialized bytes for missing nodes as read from the source store.
Implementations
Sourceimpl MissingNodePlan
impl MissingNodePlan
Sourcepub fn required_cids(&self) -> &[Cid]
pub fn required_cids(&self) -> &[Cid]
Return all required CIDs in deterministic byte order.
Sourcepub fn missing_cids(&self) -> &[Cid]
pub fn missing_cids(&self) -> &[Cid]
Return missing CIDs in deterministic byte order.