pub struct ProvedDiffPage {
pub page: DiffPage,
pub proof: DiffPageProof,
}Expand description
A bounded diff page paired with a store-independent proof for that page.
Fields
page: DiffPageDiff entries plus the cursor that should be used to request the next page, if more diffs were observed while constructing this proof.
proof: DiffPageProofProof whose verification recomputes exactly page.diffs and
page.next_cursor.