pub struct ProvedRangePage {
pub page: RangePage,
pub proof: RangePageProof,
}Expand description
A bounded range page paired with a store-independent proof for that page.
Fields
page: RangePagePage entries plus the cursor that should be used to request the next page, if more entries were observed while constructing this proof.
proof: RangePageProofProof for the page window. Verifying this proof yields exactly
page.entries.