pub struct ProximityReadSession<'map, S: Store> { /* private fields */ }Expand description
Reusable exact-read context over one immutable proximity map.
Implementations
Sourceimpl<S: Store> ProximityReadSession<'_, S>
impl<S: Store> ProximityReadSession<'_, S>
pub fn get_with<R>( &mut self, key: &[u8], read: impl for<'record> FnOnce(ProximityRecordRef<'record>) -> R, ) -> Result<Option<R>, Error>
Sourcepub fn get_lease(
&mut self,
key: &[u8],
) -> Result<Option<OwnedValueLease>, Error>
pub fn get_lease( &mut self, key: &[u8], ) -> Result<Option<OwnedValueLease>, Error>
Retain the immutable packed leaf containing one encoded exact record. Native adapters validate the record before exposing callback-scoped vector and value views over this lease.
pub fn contains_key(&mut self, key: &[u8]) -> Result<bool, Error>
pub fn scan_records( &mut self, visit: impl for<'record> FnMut(&[u8], ProximityRecordRef<'record>), ) -> Result<u64, Error>
pub fn scan_records_until<B>( &mut self, visit: impl for<'record> FnMut(&[u8], ProximityRecordRef<'record>) -> ControlFlow<B>, ) -> Result<ScanOutcome<B>, Error>
Sourcepub fn scan_records_range_until<B>(
&mut self,
start: &[u8],
end: Option<&[u8]>,
visit: impl for<'record> FnMut(&[u8], ProximityRecordRef<'record>) -> ControlFlow<B>,
) -> Result<ScanOutcome<B>, Error>
pub fn scan_records_range_until<B>( &mut self, start: &[u8], end: Option<&[u8]>, visit: impl for<'record> FnMut(&[u8], ProximityRecordRef<'record>) -> ControlFlow<B>, ) -> Result<ScanOutcome<B>, Error>
Visit a half-open exact-record range with callback-directed early
termination. This is the seekable primitive used by bounded binding
pages; start is inclusive and end is exclusive.