pub struct ProximitySearchProof {
pub source: ProximityStructuralProof,
pub accelerator_root: Option<TypedContentRoot>,
pub accelerator_objects: Vec<TypedContentObject>,
pub request: ProximitySearchRequest,
pub request_commitment: Cid,
pub result: SearchResult,
pub events: Vec<ProximitySearchEvent>,
pub claim: ProximitySearchClaim,
}Expand description
Self-contained proof for native, PQ, or HNSW search replay.
Fields
source: ProximityStructuralProofaccelerator_root: Option<TypedContentRoot>accelerator_objects: Vec<TypedContentObject>request: ProximitySearchRequestrequest_commitment: Cidresult: SearchResultevents: Vec<ProximitySearchEvent>claim: ProximitySearchClaimImplementations
Sourceimpl ProximitySearchProof
impl ProximitySearchProof
Sourcepub fn verify_for_source(
&self,
expected_descriptor: &Cid,
limits: &ContentGraphLimits,
) -> Result<ProximitySearchVerification, Error>
pub fn verify_for_source( &self, expected_descriptor: &Cid, limits: &ContentGraphLimits, ) -> Result<ProximitySearchVerification, Error>
Verify against a source descriptor CID already trusted by the caller.
Sourcepub fn verify(
&self,
limits: &ContentGraphLimits,
) -> Result<ProximitySearchVerification, Error>
pub fn verify( &self, limits: &ContentGraphLimits, ) -> Result<ProximitySearchVerification, Error>
Authenticate all supplied objects and deterministically replay the requested native or accelerator execution in an isolated store.