pub struct RangePage {
pub entries: Vec<(Vec<u8>, Vec<u8>)>,
pub next_cursor: Option<RangeCursor>,
}Expand description
A bounded page of range-scan results.
next_cursor is Some when another call should resume after the last entry
in this page. It is None when the scan reached the end bound or the end of
the tree.
Fields
entries: Vec<(Vec<u8>, Vec<u8>)>next_cursor: Option<RangeCursor>Trait Implementations
impl Eq for RangePage
impl StructuralPartialEq for RangePage