pub struct RemoteNamedRootPage {
pub roots: Vec<RemoteNamedRoot>,
pub next_after: Option<Vec<u8>>,
}Expand description
One bounded backend page of serialized named roots in raw-name order.
Fields
roots: Vec<RemoteNamedRoot>Serialized roots in ascending raw-name order.
next_after: Option<Vec<u8>>Last emitted raw name when another matching root exists.