pub struct SnapshotBundleVerification {
pub valid: bool,
pub summary: SnapshotBundleSummary,
pub reachable_nodes: usize,
pub reachable_bytes: usize,
pub missing_cids: Vec<Cid>,
pub extra_cids: Vec<Cid>,
}Expand description
Result of verifying a snapshot bundle as a self-contained tree.
Fields
valid: boolTrue when the bundle has exactly the reachable node set for its tree.
summary: SnapshotBundleSummaryValidated bundle metadata.
reachable_nodes: usizeNumber of reachable CIDs discovered from the tree root.
reachable_bytes: usizeSerialized bytes for reachable bundled nodes.
missing_cids: Vec<Cid>Reachable CIDs absent from the bundle.
extra_cids: Vec<Cid>Bundled CIDs not reachable from the tree root.