StatsPercentageChange

Struct StatsPercentageChange 

pub struct StatsPercentageChange {
Show 24 fields pub num_nodes_pct: f64, pub num_leaves_pct: f64, pub num_internal_nodes_pct: f64, pub tree_height_pct: f64, pub total_key_value_pairs_pct: f64, pub total_tree_size_bytes_pct: f64, pub avg_node_size_bytes_pct: f64, pub min_node_size_bytes_pct: f64, pub max_node_size_bytes_pct: f64, pub avg_entries_per_node_pct: f64, pub avg_fanout_pct: f64, pub min_fanout_pct: f64, pub max_fanout_pct: f64, pub avg_fill_factor_pct: f64, pub avg_leaf_fill_factor_pct: f64, pub avg_internal_fill_factor_pct: f64, pub avg_key_size_bytes_pct: f64, pub avg_value_size_bytes_pct: f64, pub min_key_size_bytes_pct: f64, pub max_key_size_bytes_pct: f64, pub min_value_size_bytes_pct: f64, pub max_value_size_bytes_pct: f64, pub total_keys_size_bytes_pct: f64, pub total_values_size_bytes_pct: f64,
}
Percentage change between two statistics objects

Contains the percentage change for each numeric metric between two TreeStats objects. Percentage change is calculated as: ((current - baseline) / baseline) * 100

Returns 0.0 for metrics where the baseline value is zero (to avoid division by zero).

Created by calling TreeStats::percentage_change.

Example

use prolly::{Config, MemStore, Prolly};

let store = MemStore::new();
let prolly = Prolly::new(store, Config::default());

// Build initial tree
let mut tree1 = prolly.create();
for i in 0..50 {
    tree1 = prolly.put(&tree1, format!("k{}", i).into_bytes(), b"v".to_vec()).unwrap();
}
let stats1 = prolly.collect_stats(&tree1).unwrap();

// Grow tree
let mut tree2 = tree1.clone();
for i in 50..100 {
    tree2 = prolly.put(&tree2, format!("k{}", i).into_bytes(), b"v".to_vec()).unwrap();
}
let stats2 = prolly.collect_stats(&tree2).unwrap();

let pct = stats2.percentage_change(&stats1);
assert!(pct.total_key_value_pairs_pct > 0.0); // Grew by some percentage

Fields

num_nodes_pct: f64num_leaves_pct: f64num_internal_nodes_pct: f64tree_height_pct: f64total_key_value_pairs_pct: f64total_tree_size_bytes_pct: f64avg_node_size_bytes_pct: f64min_node_size_bytes_pct: f64max_node_size_bytes_pct: f64avg_entries_per_node_pct: f64avg_fanout_pct: f64min_fanout_pct: f64max_fanout_pct: f64avg_fill_factor_pct: f64avg_leaf_fill_factor_pct: f64avg_internal_fill_factor_pct: f64avg_key_size_bytes_pct: f64avg_value_size_bytes_pct: f64min_key_size_bytes_pct: f64max_key_size_bytes_pct: f64min_value_size_bytes_pct: f64max_value_size_bytes_pct: f64total_keys_size_bytes_pct: f64total_values_size_bytes_pct: f64