pub struct TimestampedValue {
pub value: Vec<u8>,
pub timestamp: u64,
}Expand description
A value with an embedded timestamp for LWW ordering.
Used with the Last-Writer-Wins merge strategy to determine which value should win when concurrent modifications occur.
Serialization Format
Values are serialized as: [value bytes][8-byte big-endian timestamp]
Example
use prolly::TimestampedValue;
let tv = TimestampedValue::now(b"hello".to_vec());
let bytes = tv.to_bytes();
let restored = TimestampedValue::from_bytes(&bytes).unwrap();
assert_eq!(restored.value, b"hello");Fields
value: Vec<u8>The actual value bytes
timestamp: u64Timestamp in microseconds since epoch
Implementations
Sourceimpl TimestampedValue
impl TimestampedValue
Sourcepub fn new(value: Vec<u8>, timestamp: u64) -> Self
pub fn new(value: Vec<u8>, timestamp: u64) -> Self
Create a new timestamped value with the given timestamp.
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Serialize to bytes (value + 8-byte timestamp suffix).
Format: [value bytes][8-byte big-endian timestamp]
Sourcepub fn from_bytes(bytes: &[u8]) -> Option<Self>
pub fn from_bytes(bytes: &[u8]) -> Option<Self>
Deserialize from bytes.
Returns None if the byte slice is too short (< 8 bytes).