AsyncTransactionalStore

Trait AsyncTransactionalStore 

pub trait AsyncTransactionalStore: AsyncStore + AsyncManifestStore {
    // Provided methods
    fn supports_transactions(&self) -> bool { ... }
    async fn commit_transaction(
        &self,
        _node_writes: &[TransactionNodeWrite],
        _root_conditions: &[RootCondition],
        _root_writes: &[RootWrite],
    ) -> Result<TransactionUpdate, Error> { ... }
}
Async store support for strict atomic transaction commits.

Provided Methods

fn supports_transactions(&self) -> bool

Whether this backend can atomically commit staged nodes and roots.

async fn commit_transaction( &self, _node_writes: &[TransactionNodeWrite], _root_conditions: &[RootCondition], _root_writes: &[RootWrite], ) -> Result<TransactionUpdate, Error>

Atomically validate root conditions, write nodes, and apply root writes.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> AsyncTransactionalStore for Arc<T>

Source

fn supports_transactions(&self) -> bool

Source

async fn commit_transaction( &self, node_writes: &[TransactionNodeWrite], root_conditions: &[RootCondition], root_writes: &[RootWrite], ) -> Result<TransactionUpdate, Error>

Implementors