Reusable backend conformance checks for provider implementations.
Provider crates should run this against their SDK-backed implementation in addition to any provider-specific transactional tests.
Functions
- assert_
remote_ backend_ contract - Assert the common backend contract needed by remote prolly adapters.
- assert_
remote_ backend_ transaction_ contract - Assert the optional backend transaction contract. Providers that return
truefromsupports_transactionsshould run this in addition to the base backend contract.