AsyncProximityMap

Struct AsyncProximityMap 

pub struct AsyncProximityMap<S: AsyncStore> { /* private fields */ }

Implementations

Source

impl<S> AsyncProximityMap<SearchIo<S>>
where S: AsyncStore + Clone, S::Error: Send + Sync,

pub async fn search_with_runtime( &self, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>

Execute native async search with physical I/O derived from the shared runtime rather than from logical object consumption.

pub async fn search_with_accelerators( &self, accelerators: &AsyncAcceleratorSet, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>

Plan and execute native, eligible-exact, PQ, or HNSW search through an async-only store using the same logical planner as synchronous search.

Source

impl<S> AsyncProximityMap<S>
where S: AsyncStore + Clone, S::Error: Send + Sync,

pub async fn load(store: S, descriptor_cid: Cid) -> Result<Self, Error>

pub fn tree(&self) -> &ProximityTree

pub async fn search( &self, request: SearchRequest<'_>, control: AsyncSearchControl, ) -> Result<SearchResult, Error>