AuthenticatedProofEnvelopeVerification

Struct AuthenticatedProofEnvelopeVerification 

pub struct AuthenticatedProofEnvelopeVerification {
    pub valid: bool,
    pub signature_valid: bool,
    pub time_valid: bool,
    pub not_yet_valid: bool,
    pub expired: bool,
    pub algorithm: String,
    pub key_id: Vec<u8>,
    pub proof_bundle: Vec<u8>,
    pub context: Vec<u8>,
    pub issued_at_millis: Option<u64>,
    pub expires_at_millis: Option<u64>,
    pub nonce: Vec<u8>,
}
Verification result for an AuthenticatedProofEnvelope.

Fields

valid: bool

True when the algorithm is supported, the signature matches, and optional time bounds are valid for the supplied verification time.

signature_valid: bool

True when the algorithm is supported and the HMAC matches the envelope signing payload.

time_valid: bool

True when the optional issue/expiration bounds are valid or time checking was skipped.

not_yet_valid: bool

True when issued_at_millis is later than the supplied verification time.

expired: bool

True when expires_at_millis is less than or equal to the supplied verification time.

algorithm: String

Signature algorithm from the envelope.

key_id: Vec<u8>

Caller-defined key identifier from the envelope.

proof_bundle: Vec<u8>

Authenticated proof bundle bytes.

context: Vec<u8>

Authenticated application context bytes.

issued_at_millis: Option<u64>

Issue time from the envelope.

expires_at_millis: Option<u64>

Expiration time from the envelope.

nonce: Vec<u8>

Nonce from the envelope.