pub struct CrdtConfig {
pub strategy: MergeStrategy,
pub delete_policy: DeletePolicy,
pub timestamp_extractor: Option<TimestampExtractor>,
}Expand description
Configuration for conflict-free merging.
Controls how the CRDT merger resolves conflicts between concurrent modifications.
Example
use prolly::{CrdtConfig, MergeStrategy, DeletePolicy};
let config = CrdtConfig {
strategy: MergeStrategy::LastWriterWins,
delete_policy: DeletePolicy::UpdateWins,
timestamp_extractor: None,
};Fields
strategy: MergeStrategyThe merge strategy to use for resolving conflicts.
delete_policy: DeletePolicyPolicy for delete vs update conflicts.
timestamp_extractor: Option<TimestampExtractor>Function to extract timestamp from value (for LWW).
If None, values are assumed to be in TimestampedValue format.
If extraction fails, timestamp defaults to 0.
Implementations
Sourceimpl CrdtConfig
impl CrdtConfig
Sourcepub fn multi_value() -> Self
pub fn multi_value() -> Self
Create a new CrdtConfig with MV strategy.
Sourcepub fn custom<F>(merge_fn: F) -> Self
pub fn custom<F>(merge_fn: F) -> Self
Create a new CrdtConfig with a custom merge function.
The callback must be pure and deterministic and may be invoked more than once for a conflict while the engine changes execution paths.
Sourcepub fn with_delete_policy(self, policy: DeletePolicy) -> Self
pub fn with_delete_policy(self, policy: DeletePolicy) -> Self
Set the delete policy.