pub struct CursorWindow {
pub position_key: Option<Vec<u8>>,
pub position_value: Option<Vec<u8>>,
pub found: bool,
pub entries: Vec<(Vec<u8>, Vec<u8>)>,
pub next_cursor: Option<RangeCursor>,
}Expand description
Bounded result for a stateless cursor seek.
position_key/position_value report where the internal cursor lands for
the requested seek key. This is the exact key when found is true; otherwise
it is the closest leaf entry chosen by cursor navigation. entries are the
forward window starting at the first key greater than or equal to the seek
key, and next_cursor resumes after the last emitted entry.
Fields
position_key: Option<Vec<u8>>position_value: Option<Vec<u8>>found: boolentries: Vec<(Vec<u8>, Vec<u8>)>next_cursor: Option<RangeCursor>Trait Implementations
Sourceimpl Clone for CursorWindow
impl Clone for CursorWindow
Sourcefn clone(&self) -> CursorWindow
fn clone(&self) -> CursorWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CursorWindow
impl Debug for CursorWindow
Sourceimpl Default for CursorWindow
impl Default for CursorWindow
Sourcefn default() -> CursorWindow
fn default() -> CursorWindow
Returns the “default value” for a type. Read more
impl Eq for CursorWindow
Sourceimpl PartialEq for CursorWindow
impl PartialEq for CursorWindow
impl StructuralPartialEq for CursorWindow