SnapshotManager

Struct SnapshotManager 

pub struct SnapshotManager<'a, S: Store> { /* private fields */ }
Convenience API for branch, tag, checkpoint, or custom snapshot roots.

Implementations

Source

impl<'a, S: Store> SnapshotManager<'a, S>

pub fn new(prolly: &'a Prolly<S>, namespace: SnapshotNamespace) -> Self

Create a manager for namespace using an existing Prolly manager.

pub fn namespace(&self) -> &SnapshotNamespace

Return the namespace used by this manager.

pub fn root_name(&self, id: impl AsRef<[u8]>) -> Vec<u8>

Build a durable named-root key from a namespace-local id.

pub fn load(&self, id: impl AsRef<[u8]>) -> Result<Option<Tree>, Error>
where S: ManifestStore,

Load one snapshot by namespace-local id.

pub fn load_many<I, Id>(&self, ids: I) -> Result<SnapshotSelection, Error>
where S: ManifestStore, I: IntoIterator<Item = Id>, Id: AsRef<[u8]>,

Load several snapshots by namespace-local id.

pub fn publish(&self, id: impl AsRef<[u8]>, tree: &Tree) -> Result<(), Error>
where S: ManifestStore,

Publish or replace a snapshot.

pub fn publish_at_millis( &self, id: impl AsRef<[u8]>, tree: &Tree, timestamp_millis: u64, ) -> Result<(), Error>
where S: ManifestStore,

Publish or replace a snapshot with an explicit timestamp.

pub fn delete(&self, id: impl AsRef<[u8]>) -> Result<(), Error>
where S: ManifestStore,

Delete a snapshot. Deleting a missing snapshot is not an error.

pub fn compare_and_swap( &self, id: impl AsRef<[u8]>, expected: Option<&Tree>, replacement: Option<&Tree>, ) -> Result<NamedRootUpdate, Error>
where S: ManifestStore,

Atomically update a snapshot when the current tree matches expected.

pub fn compare_and_swap_at_millis( &self, id: impl AsRef<[u8]>, expected: Option<&Tree>, replacement: Option<&Tree>, timestamp_millis: u64, ) -> Result<NamedRootUpdate, Error>
where S: ManifestStore,

Atomically update a snapshot with an explicit timestamp.

pub fn list(&self) -> Result<Vec<SnapshotRoot>, Error>

List all snapshots in this namespace.