pub struct SyncBlobStoreAsAsync<S> { /* private fields */ }Expand description
Adapter that exposes an existing synchronous BlobStore as an
AsyncBlobStore.
This adapter calls the synchronous blob store directly and does not spawn
blocking work. Use TokioBlockingBlobStore when a Tokio application needs
to adapt a blocking blob backend without stalling async worker threads.
Implementations
Sourceimpl<S> SyncBlobStoreAsAsync<S>
impl<S> SyncBlobStoreAsAsync<S>