pub trait IndexedStore:
Store
+ ManifestStore
+ TransactionalStore {
// Provided method
fn confirm_indexed_publication(&self, trees: &[&Tree]) -> Result<(), Error> { ... }
}Expand description
Store contract used by the canonical single-root index coordinator.
Immutable nodes may be published before the visibility transition because they are content addressed and unreachable nodes are safe to reclaim. The canonical collection root is always validated and advanced through a strict store transaction, so a successful transaction is the only visibility transition.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".